import string

"""
details.py

Build and installation details for this PyKDE component.

Copyright (C) 2003 David Boddie <david@boddie.org.uk>
Copyright (C) 2005 Paul Boddie <paul@boddie.org.uk>

This software is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License as
published by the Free Software Foundation; either version 2 of
the License, or (at your option) any later version.

This software is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public
License along with this library; see the file COPYING
If not, write to the Free Software Foundation, Inc.,
51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA

"""

def find_details():

    details = \
    {
        # Project name - the filename of the Python module should
        # be derived from this: e.g. DefaultPython -> defaultpython.py
        "name":             "hCalendarPlugin",
        
        # A pretty name for this module and its description
        "pretty name":      "hCalendar event discovery plugin",
        "comment":          "Finds hCalendar events in Web pages",
        
        # Change this function or class name in your Python module to match
        # the name of the factory class.
        "factory":          "FactoryClass",
        
        # Destination filename in each destination for the icons described
        # below.
        "icon":             "hcalendarplugin.png",
        
        # Specific KParts attributes
        "parent":           "konqueror",
        "C++ factory":      ("init_", "libhcalendarplugin")
    }
    
    requires = \
    {
        "library":     "pykpart_launcher.cpp",
        
        # Specify other libraries beneath the Python library directory.
        # A None value for the path causes the module to be searched for
        # within the Python library directories.
        "pyqt": [], "pykde": [],
        
        # Specify other libraries beneath the Python library directory.
        # A None value for the path causes the module to be searched for
        # within the Python library directories.
        "python":       [],
        
        # Specify other items to include alongside the module in its own
        # directory.
        "other items":  ["hCalendar/__init__.py", "hCalendar/Form.py",
            "hCalendar/Reader.py", "hCalendar/UI.py"]
    }
    
    provides = \
    {
        ".py":
        {
            "filename":     string.lower(details["name"]),
            "directory":    string.lower(details["name"]),
            "destination":  "%(kde dir)s/share/apps"
        },
        
        ".so":
        {
            "name":         string.lower(details["name"]),
            "filename":     "lib" + string.lower(details["name"]),
            "destination":  "%(kde dir)s/lib/kde3"
        },
        
        ".la":
        {
            "contents":     linking_template,
            "filename":     "lib" + string.lower(details["name"]),
            "destination":  "%(kde dir)s/lib/kde3"
        },
        
        ".desktop":
        {
            # Give the path beneath which the desktop file should be stored.
            "filename":     string.lower(details["name"]),
            "destination":  "%(kde dir)s/share/applnk/.hidden",
            "contents":     desktop_template
        },
        
        ".rc":
        {
            # Give the path beneath which the rc file should be stored.
            "filename":     string.lower(details["name"]),
            "destination":  "%(kde dir)s/share/apps/khtml/kpartplugins",
            "contents":     rc_template
        },
        
        "icons":
        {
            "destination":  "%(kde dir)s/share/icons/",
            
            # The section under which the icon will be stored for each theme
            # and size.
            "icon type":    "actions",
            
            "themes":
            {
              #   Theme          Size    Source icon
                "hicolor":
                {
                  "22x22": [("Icons/image-22x22.png", "hcalendarplugin.png")],
                  "16x16": [("Icons/image-16x16.png", "hcalendarplugin.png")]
                },
                "crystalsvg":
                {
                  "22x22": [("Icons/image-22x22.png", "hcalendarplugin.png")],
                  "16x16": [("Icons/image-16x16.png", "hcalendarplugin.png")]
                },
                "kdeclassic":
                {
                  "22x22": [("Icons/image-22x22.png", "hcalendarplugin.png")],
                  "16x16": [("Icons/image-16x16.png", "hcalendarplugin.png")]
                }
            }
        }
    }
    
    return details, requires, provides


desktop_template = \
"""[Desktop Entry]
Name=%(pretty name)s
Comment=%(comment)s
Icon=%(icon)s
X-KDE-ParentApp=%(parent)s
"""

rc_template = \
"""<!DOCTYPE kpartplugin>
<kpartplugin name="%(name)s" library="%(lib)s">
<MenuBar>
  <Menu name="tools"><Text>&amp;Tools</Text>
    <Action name="finditems"/>
  </Menu>
</MenuBar>
</kpartplugin>
"""

unused = """<ToolBar name="extraToolBar">
  <Action name="finditems"/>
</ToolBar>
"""

def hints():

    # Provide hints on how to display the details returned by find_details
    # in a graphical user interface. The dictionary returned contains entries
    # for the details, requires and provides dictionaries, each of which
    # takes the form of a substitution dictionary.
    # In addition, the titles of each dictionary can be substituted if
    # entries for "Details", "Provides" and "Requires" are included.
    
    hint_dict = \
    {
        "Details":      "&Details",
        "Requires":     "&Requires",
        "Provides":     "Provides",    # not usually used
        "Information":  "&Information",
        
        # Substitute the following keys with their corresponding values when
        # displaying information from the provides dictionary.
        
        "provides":
        {
            ".py":      "&Python",
            ".desktop": "Desk&top",
            ".rc":      "I&nterface"
        }
    }
    
    return hint_dict


def info():

    # Return information on the component in HTML format.
    return component_info_html

component_info_html = \
"""<html>
<head>
  <meta http-equiv="Content-Type" content="text/html; charset=utf-8">
  <title>Information about the hCalendar KPart</title>
</head>

<body>

<h1>hCalendar</h1>

<h2>Description</h2>

<p>
  A KPart written in Python which discovers hCalendar events embedded in Web pages.
</p>

<h2>Usage</h2>

<p>
  Once installed, a relevant menu entry should be accessible from Konqueror's
  <em>Tools</em> menu. Selecting this entry should result in the discovery of
  any embedded hCalendar events to appear in an event list window.
</p>

<hr>

<address>
Paul Boddie
&lt;<a href="mailto:paul@boddie.org.uk">paul@boddie.org.uk</a>&gt;
</address>

</body>
</html>
"""


# Do not change anything below this line. -------------------------------------

linking_template = \
"""
# %(lib)s.la - a libtool library file
# Generated by build.py
#
# Please DO NOT delete this file!
# It is necessary for linking the library.

# The name that we can dlopen(3).
dlname='%(lib)s.so'

# Names of this library.
library_names='%(lib)s.so %(lib)s.so %(lib)s.so'

# The name of the static archive.
old_library=''

# Libraries that this one depends upon.
dependency_libs='%(deps)s'

# Version information for %(lib)s.
current=0
age=0
revision=0

# Is this an already installed library?
installed=yes

# Files to dlopen/dlpreopen
dlopen=''
dlpreopen=''

# Directory that this library needs to be installed in:
libdir='%(libdest)s'
"""
