#!/usr/bin/env python

"""
hCalendar element extraction: http://microformats.org/wiki/hcalendar

Copyright (C) 2005 Paul Boddie <paul@boddie.org.uk>

This software is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License as
published by the Free Software Foundation; either version 2 of
the License, or (at your option) any later version.

This software is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public
License along with this library; see the file COPYING
If not, write to the Free Software Foundation, Inc.,
51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
"""

import qtxmldom
from RDFCalendar.Format import permitted_elements, permitted_attributes, \
    datetime_attributes
import RDFCalendar.FormatWriters

def get_items(part):
    doc = qtxmldom.fromNode(part.document())
    items = []
    for ELEMENT in permitted_elements["VCALENDAR"]:
        element = ELEMENT.lower()
        for top in get_properties(doc, element):
            item = {}
            for ATTRIBUTE in permitted_attributes[ELEMENT]:
                attribute = ATTRIBUTE.lower()
                values = get_properties(top, attribute)
                if ATTRIBUTE in datetime_attributes:
                    value = get_date(values)
                else:
                    value = get_text(values)
                if value != "":
                    item[attribute] = value
            item["top"] = top
            item["type"] = element
            items.append(item)
    return items

def serialise_items(items, f):
    format_writer = RDFCalendar.FormatWriters.iCalendarWriter(f, compact=1, do_not_fold=1)
    format_writer.start_element("VCALENDAR")
    format_writer.write_attribute("VERSION", value="1.0")
    for item in items:
        ELEMENT = item["type"].upper()
        format_writer.start_element(ELEMENT)
        for ATTRIBUTE in permitted_attributes[ELEMENT]:
            attribute = ATTRIBUTE.lower()
            if item.has_key(attribute):
                value = item[attribute]
                format_writer.write_attribute(ATTRIBUTE, value=value)
        format_writer.end_element(ELEMENT)
    format_writer.end_element("VCALENDAR")

def get_html(l):
    if len(l) != 0:
        return l[0].toUnicode()
    else:
        return u""

def get_text(l):
    if len(l) != 0:
        text = []
        for n in l[0].childNodes:
            if n.nodeType == n.TEXT_NODE:
                text.append(n.nodeValue)
            elif n.nodeType == n.ELEMENT_NODE:
                text.append(get_text([n]))
        return u"".join(text).replace("\r", "").replace("\n", " ").strip()
    else:
        return u""

def get_date(l):
    if len(l) != 0:
        return l[0].getAttribute("title")
    else:
        return u""

def get_properties(top, name):
    l = []
    for e in top.getElementsByTagName("*"):
        if is_property(e, name):
            l.append(e)
    return l

def is_property(e, name):
    return name in e.getAttribute("class").split()

# vim: tabstop=4 expandtab shiftwidth=4
