#!/usr/bin/env python

"""
hCalendar exporter: http://microformats.org/wiki/hcalendar

Copyright (C) 2005 Paul Boddie <paul@boddie.org.uk>

This software is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License as
published by the Free Software Foundation; either version 2 of
the License, or (at your option) any later version.

This software is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public
License along with this library; see the file COPYING
If not, write to the Free Software Foundation, Inc.,
51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
"""

from qt import QMessageBox, QScrollView, QWidgetItem
from kdecore import i18n, KInstance, KLibFactory, KShortcut
from kparts import KParts
from kdeui import KAction
from kfile import KFileDialog

import hCalendar.Form
import hCalendar.Reader
import codecs

class ItemsWidget(hCalendar.Form.Items):

    "A widget providing a list of items and some controls."

    def __init__(self, *args, **kw):
        hCalendar.Form.Items.__init__(self, *args, **kw)
        self.khtmlpart = None
        self.reset()

    def reset(self):
        self.item_list.setNumRows(0)
        self.items = []

    def addItems(self, items):
        current = len(self.items)
        self.items = self.items + items
        self.item_list.setNumRows(len(self.items))
        for item in items:
            self.item_list.setText(current, 0, item.get("summary", ""))
            self.item_list.setText(current, 1, item.get("dtstart", ""))
            self.item_list.setText(current, 2, item.get("dtend", ""))
            current += 1
        width = self.item_list.width()
        for column in range(0, self.item_list.numCols()):
            self.item_list.setColumnWidth(column, width * (1.0/3))

    def cancelPlugin(self):
        self.close()

    def clearItems(self):
        self.reset()

    def rescanPage(self):
        if self.khtmlpart is not None:
            self.addItems(hCalendar.Reader.get_items(self.khtmlpart))

    def exportItems(self):
        filename = KFileDialog.getSaveFileName()
        # NOTE: Use UTF-8 encoding for now.
        f = codecs.open(unicode(filename), "wb", "utf-8")
        hCalendar.Reader.serialise_items(self.items, f)
        f.close()

class ItemsPlugin(KParts.Plugin):

    "A KParts plug-in which provides access to the items list."

    def __init__(self, parent=None, name=None):

        KParts.Plugin.__init__(self, parent, name)

        self._action = KAction(
            i18n("Find hCalendar items..."),
            "hcalendarplugin",
            KShortcut(i18n("Ctrl+Shift+H")),
            self.findItems,
            self.actionCollection(),
            "finditems"
            )
        self.items = ItemsWidget()

    def findItems(self):

        # The parent is assumed to be a KHTMLPart.

        khtmlpart = self.parent()

        if not khtmlpart.inherits("KHTMLPart"):
            title = i18n("Cannot find items")
            text = i18n("Only HTML documents can be searched for hCalendar items.")

            QMessageBox.warning(None, title, text)
            return

        self.items.khtmlpart = khtmlpart
        self.items.addItems(hCalendar.Reader.get_items(khtmlpart))
        self.items.show()

# vim: tabstop=4 expandtab shiftwidth=4
